@@ -3,7 +3,7 @@ PyNeb - python package for the analysis of emission lines
 """
 
 __all__ = []
-__version__ = '1.0.4'
+__version__ = '1.0.5'
 
 import sys
 from numpy.version import version as numpy_version
@@ -20,10 +20,6 @@ try:
         log_.warn('Numpy version >= 1.5.1 needed, seems you have {0}'.format(numpy_version), calling='PyNeb')
 except:
     log_.warn('I do not understand what is your version of numpy: {0}, report this to PyNeb group'.format(numpy_version), calling='PyNeb')
-try:
-    import pyfits
-except:
-    log_.warn('PyFITS package needed', calling='PyNeb')
 
 from utils.manage_atomic_data import _ManageAtomicData
 atomicData = _ManageAtomicData()
