@@ -56,6 +56,17 @@ class _Config(object):
             self.INSTALLED['Chianti'] = True
         else:
             self.INSTALLED['Chianti'] = False
+        try:
+            import pyfits
+            self.INSTALLED['pyfits'] = True
+            self.INSTALLED['pyfits from astropy'] = False
+        except:
+            self.INSTALLED['pyfits'] = False
+            try:
+                import astropy.io.fits as pyfits
+                self.INSTALLED['pyfits from astropy'] = True
+            except:
+                self.INSTALLED['pyfits from astropy'] = False
         
         self.DataFiles = {}
             
